<p align="center">
  <img width="120" src="https://github.com/etesync/etesync-web/blob/master/src/images/logo.svg" />
  <h1 align="center">Etebase - Encrypt Everything</h1>
</p>

A Python library for Etebase

This package is implemented in Rust and exposes a Python API for people to use.

![GitHub tag](https://img.shields.io/github/tag/etesync/etebase-py.svg)
[![PyPI](https://img.shields.io/pypi/v/etebase.svg)](https://pypi.python.org/pypi/etebase/)
[![Build Status](https://travis-ci.com/etesync/etebase-py.svg?branch=master)](https://travis-ci.com/etesync/etebase-py)
[![Chat on freenode](https://img.shields.io/badge/irc.freenode.net-%23EteSync-blue.svg)](https://webchat.freenode.net/?channels=#etesync)

# Build

## Install deps

```
pip install wheel setuptools setuptools-rust
```

## Build

```
python setup.py bdist_wheel
```
